@@ -5,7 +5,7 @@ use strict;
 use 5.008003;
 no warnings 'utf8';
 
-our $VERSION = '1.016_07';
+our $VERSION = '1.018_01';
 
 use Encode                qw( decode );
 use File::Basename        qw( basename );
@@ -449,7 +449,7 @@ sub run {
                             schema => $schema,
                         }
                     };
-                    if ( $table eq $hidden ) { # prompt
+                    if ( $table eq $hidden ) { # prompt "table-menu"
                         my $old_idx_hdn = 0;
 
                         HIDDEN: while ( 1 ) {
@@ -626,7 +626,7 @@ App::DBBrowser - Browse SQLite/MySQL/PostgreSQL databases and their tables inter
 
 =head1 VERSION
 
-Version 1.016_07
+Version 1.018_01
 
 =head1 DESCRIPTION
 
@@ -643,7 +643,7 @@ Matthäus Kiem <cuer2s@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012-2015 Matthäus Kiem.
+Copyright (C) 2012-2016 Matthäus Kiem.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl 5.10.0. For
 details, see the full text of the licenses in the file LICENSE.
