@@ -6,7 +6,7 @@ use strict;
 use 5.008003;
 no warnings 'utf8';
 
-our $VERSION = '1.016_07';
+our $VERSION = '1.018_01';
 
 use File::Basename        qw( basename fileparse );
 use File::Spec::Functions qw( catfile );
@@ -14,7 +14,7 @@ use FindBin               qw( $RealBin $RealScript );
 #use Pod::Usage            qw( pod2usage );  # "require"-d
 
 use Term::Choose           qw( choose );
-use Term::Choose::Util     qw( insert_sep print_hash choose_a_number choose_a_subset choose_multi choose_dirs );
+use Term::Choose::Util     qw( insert_sep print_hash choose_a_number choose_a_subset change_config choose_dirs choose_a_dir );
 use Term::ReadLine::Simple qw();
 
 use App::DBBrowser::DB;
@@ -56,11 +56,14 @@ sub defaults {
             binary_filter        => 0,
         },
         insert => {
+        # Input
             input_modes          => [ 'Cols', 'Rows', 'Multi-row', 'File' ],
-            parse_mode           => 0,
+            files_dir            => undef,
             file_encoding        => 'UTF-8',
             max_files            => 15,
-        # Text::CSV:
+        # Parsing
+            parse_mode           => 0,
+            # Text::CSV:
             sep_char             => ',',
             quote_char           => '"',
             escape_char          => '"',
@@ -71,9 +74,12 @@ sub defaults {
             blank_is_undef       => 1,
             binary               => 1,
             empty_is_undef       => 0,
-        # split:
+            # split:
             i_r_s                => '\n',
             i_f_s                => ',',
+        # create table defaults:
+            id_col_name          => 'ID_a',
+            default_data_type    => 'TEXT',
         }
     };
     return $defaults                   if ! $section;
@@ -86,12 +92,14 @@ sub __sub_menus_insert {
     my ( $self, $group ) = @_;
     my $sub_menus_insert = {
         main_insert => [
-            { name => 'input_modes',       text => "- Read",          section => 'insert' },
-            { name => 'parse_mode',        text => "- Parse-mode",    section => 'insert' },
-            { name => '_module_Text_CSV',  text => "- conf T::CSV",   section => 'insert' },
-            { name => '_parse_with_split', text => "- conf 'split'",  section => 'insert' },
-            { name => 'file_encoding',     text => "- File Encoding", section => 'insert' },
-            { name => 'max_files',         text => "- File History",  section => 'insert' },
+            { name => 'input_modes',           text => "- Read",          section => 'insert' },
+            { name => 'files_dir',             text => "- File Dir",      section => 'insert' },
+            { name => 'file_encoding',         text => "- File Encoding", section => 'insert' },
+            { name => 'max_files',             text => "- File History",  section => 'insert' },
+            { name => 'parse_mode',            text => "- Parse-mode",    section => 'insert' },
+            { name => '_module_Text_CSV',      text => "- conf T::CSV",   section => 'insert' },
+            { name => '_parse_with_split',     text => "- conf 'split'",  section => 'insert' },
+            { name => 'create_table_defaults', text => "- Create-table",  section => 'insert' },
         ],
         _module_Text_CSV => [
             { name => '_csv_char',    text => "- *_char attributes", section => 'insert' },
@@ -166,11 +174,8 @@ sub __config_insert {
                     my $prompt = 'Input Modes:';
                     $self->__opt_choose_a_list( $opt_type, $section, $option, $available, $prompt );
             }
-            elsif ( $option eq 'parse_mode' ) {
-                my $prompt = 'Parsing CSV files';
-                my $list = [ 'Text::CSV', 'split', 'Spreadsheet::Read' ];
-                my $sub_menu = [ [ $option, "  Use", $list ] ];
-                $self->__opt_choose_multi( $opt_type, $section, $sub_menu, $prompt );
+            elsif ( $option eq 'files_dir' ) {
+                $self->__opt_choose_a_dir( $opt_type, $section, $option );
             }
             elsif ( $option eq 'file_encoding' ) {
                 my $items = [
@@ -179,6 +184,13 @@ sub __config_insert {
                 my $prompt = 'Encoding CSV files';
                 $self->__group_readline( $opt_type, $section, $items, $prompt );
             }
+
+            elsif ( $option eq 'parse_mode' ) {
+                my $prompt = 'Parsing CSV files';
+                my $list = [ 'Text::CSV', 'split', 'Spreadsheet::Read' ];
+                my $sub_menu = [ [ $option, "  Use", $list ] ];
+                $self->__opt_change_config( $opt_type, $section, $sub_menu, $prompt );
+            }
             elsif ( $option eq '_csv_char' ) {
                 my $items = [
                     { name => 'sep_char',    prompt => "sep_char   " },
@@ -197,7 +209,7 @@ sub __config_insert {
                     [ 'blank_is_undef',      "- blank_is_undef",      [ 'NO', 'YES' ] ],
                     [ 'empty_is_undef',      "- empty_is_undef",      [ 'NO', 'YES' ] ],
                 ];
-                $self->__opt_choose_multi( $opt_type, $section, $sub_menu, $prompt );
+                $self->__opt_change_config( $opt_type, $section, $sub_menu, $prompt );
             }
             elsif ( $option eq '_parse_with_split' ) {
                 my $items = [
@@ -207,10 +219,14 @@ sub __config_insert {
                 my $prompt = 'Separators (regexp)';
                 $self->__group_readline( $opt_type, $section, $items, $prompt );
             }
-            elsif ( $option eq 'max_files' ) {
-                my $digits = 3;
-                my $prompt = '"Max file history"';
-                $self->__opt_number_range( $opt_type, $section, $option, $prompt, $digits );
+
+            elsif ( $option eq 'create_table_defaults' ) {
+                my $items = [
+                    { name => 'id_col_name',       prompt => "Default ID col name  " },
+                    { name => 'default_data_type', prompt => "Default data type" },
+                ];
+                my $prompt = 'Create-table defaults';
+                $self->__group_readline( $opt_type, $section, $items, $prompt );
             }
             else { die "Unknown option: $option" }
         }
@@ -393,20 +409,20 @@ sub __set_options {
                 my $prompt = 'SQL statement: ';
                 my $list = [ 'Lk0', 'Lk1' ];
                 my $sub_menu = [ [ $option, "  Lock Mode", $list ] ];
-                $self->__opt_choose_multi( $opt_type, $section, $sub_menu, $prompt );
+                $self->__opt_change_config( $opt_type, $section, $sub_menu, $prompt );
             }
             elsif ( $option eq 'metadata' ) {
                 my $prompt = 'DB/schemas/tables: ';
                 my $list = $no_yes;
                 my $sub_menu = [ [ $option, "  Add metadata", $list ] ];
-                $self->__opt_choose_multi( $opt_type, $section, $sub_menu, $prompt );
+                $self->__opt_change_config( $opt_type, $section, $sub_menu, $prompt );
             }
             elsif ( $option eq '_parentheses' ) {
                 my $sub_menu = [
                     [ 'parentheses_w', "- Parens in WHERE",     [ 'NO', 'YES' ] ],
                     [ 'parentheses_h', "- Parens in HAVING TO", [ 'NO', 'YES' ] ],
                 ];
-                $self->__opt_choose_multi( $opt_type, $section, $sub_menu );
+                $self->__opt_change_config( $opt_type, $section, $sub_menu );
             }
             elsif ( $option eq 'operators' ) {
                 my $available = $self->{info}{avail_operators};
@@ -417,7 +433,7 @@ sub __set_options {
                 my $prompt = 'Choose: ';
                 my $list = [ 0, 1, 2, 3, 4 ];
                 my $sub_menu = [ [ $option, "  Mouse mode", $list ] ];
-                $self->__opt_choose_multi( $opt_type, $section, $sub_menu, $prompt );
+                $self->__opt_change_config( $opt_type, $section, $sub_menu, $prompt );
             }
             elsif ( $option eq '_menu_memory' ) {
                 my $prompt = 'Choose: ';
@@ -426,7 +442,7 @@ sub __set_options {
                     [ 'menu_sql_memory',     "- SQL    Menu",  [ 'Simple', 'Memory' ] ],
                     [ 'menus_db_memory',     "- DB     Menus", [ 'Simple', 'Memory' ] ],
                 ];
-                $self->__opt_choose_multi( $opt_type, $section, $sub_menu, $prompt );
+                $self->__opt_change_config( $opt_type, $section, $sub_menu, $prompt );
             }
             elsif ( $option eq '_table_expand' ) {
                 my $prompt = 'Choose: ';
@@ -434,7 +450,7 @@ sub __set_options {
                     [ 'keep_header',  "- Table Header", [ 'Simple', 'Each page' ] ],
                     [ 'table_expand', "- Table Rows",   [ 'Simple', 'Expand fast back', 'Expand' ] ],
                 ];
-                $self->__opt_choose_multi( $opt_type, $section, $sub_menu, $prompt );
+                $self->__opt_change_config( $opt_type, $section, $sub_menu, $prompt );
             }
             else { die "Unknown option: $option" }
         }
@@ -442,9 +458,9 @@ sub __set_options {
 }
 
 
-sub __opt_choose_multi {
+sub __opt_change_config {
     my ( $self, $opt_type, $section, $sub_menu, $prompt ) = @_;
-    my $changed = choose_multi( $sub_menu, $self->{$opt_type}{$section}, { prompt => $prompt } );
+    my $changed = change_config( $sub_menu, $self->{$opt_type}{$section}, { prompt => $prompt } );
     return if ! $changed;
     $self->{info}{write_config}++;
 }
@@ -498,6 +514,18 @@ sub __group_readline {
 }
 
 
+sub __opt_choose_a_dir {
+    my ( $self, $opt_type, $section, $option ) = @_;
+    my $current = $self->{$opt_type}{$section}{$option};
+    # Choose_a_dir
+    my $dir = choose_a_dir( { mouse => $self->{opt}{table}{mouse}, current => $current } );
+    return if ! length $dir;
+    $self->{$opt_type}{$section}{$option} = $dir;
+    $self->{info}{write_config}++;
+    return;
+}
+
+
 sub __opt_choose_dirs {
     my ( $self, $opt_type, $section, $option ) = @_;
     my $current = $self->{$opt_type}{$section}{$option};
@@ -651,7 +679,7 @@ sub __database_setting {
                     }
                 }
                 my $prompt = 'Required fields (' . $db_plugin . '):';
-                $self->__opt_choose_multi( $opt_type, $section, $sub_menu, $prompt );
+                $self->__opt_change_config( $opt_type, $section, $sub_menu, $prompt );
                 next GROUP;
             }
             elsif ( $group eq 'env_variables' ) {
@@ -669,7 +697,7 @@ sub __database_setting {
                     }
                 }
                 my $prompt = 'Use ENV variables (' . $db_plugin . '):';
-                $self->__opt_choose_multi( $opt_type, $section, $sub_menu, $prompt );
+                $self->__opt_change_config( $opt_type, $section, $sub_menu, $prompt );
                 next GROUP;
             }
             elsif ( $group eq 'read_argument' ) {
@@ -700,7 +728,7 @@ sub __database_setting {
                     }
                 }
                 my $prompt = 'Options (' . $db_plugin . '):';
-                $self->__opt_choose_multi( $opt_type, $section, $sub_menu, $prompt );
+                $self->__opt_change_config( $opt_type, $section, $sub_menu, $prompt );
                 next GROUP;
             }
             elsif ( $group eq 'sqlite_dir' ) {
